from django.conf import settings
from appconf import AppConf


class ImageCroppingAppConf(AppConf):
    JQUERY_URL = 'https://ajax.googleapis.com/ajax/libs/jquery/1.11.3/jquery.min.js'
    THUMB_SIZE = (300, 300)
    SIZE_WARNING = False



def max_cropping(width, height, image_width, image_height, free_crop=False):
    if free_crop:
        return [0, 0, image_width, image_height]

    ratio = width / float(height)
    if image_width < image_height * ratio:
        # width fits fully, height needs to be cropped
        offset = int(round((image_height - (image_width / ratio)) / 2))
        return [0, offset, image_width, image_height - offset]

    # height fits fully, width needs to be cropped
    offset = int(round((image_width - (image_height * ratio)) / 2))
    return [offset, 0, image_width - offset, image_height]



from __future__ import unicode_literals
from . import widgets


class ImageCroppingMixin(object):
    def formfield_for_dbfield(self, db_field, **kwargs):
        crop_fields = getattr(self.model, 'crop_fields', {})
        if db_field.name in crop_fields:
            target = crop_fields[db_field.name]
            if target['fk_field']:
                # it's a ForeignKey
                kwargs['widget'] = widgets.CropForeignKeyWidget(
                    db_field.rel,
                    field_name=target['fk_field'],
                    admin_site=self.admin_site,
                )
            elif target['hidden']:
                # it's a hidden ImageField
                kwargs['widget'] = widgets.HiddenImageCropWidget
            else:
                # it's a regular ImageField
                kwargs['widget'] = widgets.ImageCropWidget

        return super(ImageCroppingMixin, self).formfield_for_dbfield(db_field, **kwargs)
